numpy.recarray
==============

.. currentmodule:: numpy

.. autoclass:: recarray

   

   .. HACK
      .. autosummary::
         :toctree:
      
         recarray.__init__
         recarray.all
         recarray.any
         recarray.argmax
         recarray.argmin
         recarray.argsort
         recarray.astype
         recarray.byteswap
         recarray.choose
         recarray.clip
         recarray.compress
         recarray.conj
         recarray.conjugate
         recarray.copy
         recarray.cumprod
         recarray.cumsum
         recarray.diagonal
         recarray.dot
         recarray.dump
         recarray.dumps
         recarray.field
         recarray.fill
         recarray.flatten
         recarray.getfield
         recarray.item
         recarray.itemset
         recarray.max
         recarray.mean
         recarray.min
         recarray.newbyteorder
         recarray.nonzero
         recarray.prod
         recarray.ptp
         recarray.put
         recarray.ravel
         recarray.repeat
         recarray.reshape
         recarray.resize
         recarray.round
         recarray.searchsorted
         recarray.setasflat
         recarray.setfield
         recarray.setflags
         recarray.sort
         recarray.squeeze
         recarray.std
         recarray.sum
         recarray.swapaxes
         recarray.take
         recarray.tofile
         recarray.tolist
         recarray.tostring
         recarray.trace
         recarray.transpose
         recarray.var
         recarray.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         recarray.T
         recarray.base
         recarray.ctypes
         recarray.data
         recarray.dtype
         recarray.flags
         recarray.flat
         recarray.imag
         recarray.itemsize
         recarray.nbytes
         recarray.ndim
         recarray.real
         recarray.shape
         recarray.size
         recarray.strides

